@@ -8,6 +8,12 @@ LOGGER = logging.getLogger(__name__)
 
 
 class APIBlueprint(Blueprint):
+    """Extended blueprint that exposes more convenient methods to develop APIs
+    
+    Arguments:
+        tags: List of openapi tags that apply to all views registered in this blueprint
+    """
+
     def __init__(self, tags: Iterable[str] = None):
         super().__init__(
             self.get_caller_module_name().replace(".", "-"),
